@@ -7,7 +7,12 @@ from zope import component
 from zope.event import notify
 from zope.lifecycleevent import ObjectModifiedEvent
 from zope.filerepresentation.interfaces import IFileFactory
-from zope.app.container.interfaces import INameChooser
+try:
+    # Plone >= 4.1
+    from zope.container.interfaces import INameChooser
+except ImportError:
+    # Legacy Plone
+    from zope.app.container.interfaces import INameChooser
 from plone.i18n.normalizer.interfaces import IIDNormalizer
 
 from Products.Archetypes.event import ObjectInitializedEvent
